@@ -1,23 +1,24 @@
+"""din http://www.uif.shcp.gob.mx/recepcion/din"""
 from decimal import Decimal
 from datetime import datetime, date, time
 from collections.abc import Sequence
-from ...cfdi import CFDI, XElement
+from ... import CFDI, XElement, ScalarMap
 
 
-class FinanciamientoBursatilType(XElement):
+class FinanciamientoBursatilType(ScalarMap):
+    """
+    
+    :param fecha_emision:
+    :param monto_solicitado:
+    :param monto_recibido:
+    """
+    
     def __init__(
             self,
             fecha_emision: date = None,
             monto_solicitado: str = None,
             monto_recibido: str = None,
     ): 
-        """
-        
-        :param fecha_emision:
-        :param monto_solicitado:
-        :param monto_recibido:
-        """
-        
         super().__init__({
             'FechaEmision': fecha_emision,
             'MontoSolicitado': monto_solicitado,
@@ -25,22 +26,30 @@ class FinanciamientoBursatilType(XElement):
         })
         
 
-class DetalleAcreedoresType(XElement):
+class DetalleAcreedoresType(ScalarMap):
+    """
+    
+    :param tipo_persona_acreedor:
+    """
+    
     def __init__(
             self,
             tipo_persona_acreedor: TipoPersonaType | dict | Sequence[TipoPersonaType | dict] = None,
     ): 
-        """
-        
-        :param tipo_persona_acreedor:
-        """
-        
         super().__init__({
             'TipoPersonaAcreedor': tipo_persona_acreedor,
         })
         
 
-class DatosPrestamoNoFinType(XElement):
+class DatosPrestamoNoFinType(ScalarMap):
+    """
+    
+    :param detalle_acreedores:
+    :param monto_prestamo:
+    :param moneda:
+    :param plazo_meses:
+    """
+    
     def __init__(
             self,
             detalle_acreedores: DetalleAcreedoresType | dict,
@@ -48,14 +57,6 @@ class DatosPrestamoNoFinType(XElement):
             moneda: str = None,
             plazo_meses: str = None,
     ): 
-        """
-        
-        :param detalle_acreedores:
-        :param monto_prestamo:
-        :param moneda:
-        :param plazo_meses:
-        """
-        
         super().__init__({
             'DetalleAcreedores': detalle_acreedores,
             'MontoPrestamo': monto_prestamo,
@@ -64,22 +65,32 @@ class DatosPrestamoNoFinType(XElement):
         })
         
 
-class PrestamoNoFinancieroType(XElement):
+class PrestamoNoFinancieroType(ScalarMap):
+    """
+    
+    :param datos_prestamo:
+    """
+    
     def __init__(
             self,
             datos_prestamo: DatosPrestamoNoFinType | dict | Sequence[DatosPrestamoNoFinType | dict] = None,
     ): 
-        """
-        
-        :param datos_prestamo:
-        """
-        
         super().__init__({
             'DatosPrestamo': datos_prestamo,
         })
         
 
-class DatosPrestamoType(XElement):
+class DatosPrestamoType(ScalarMap):
+    """
+    
+    :param tipo_institucion:
+    :param institucion:
+    :param tipo_credito:
+    :param monto_prestamo:
+    :param moneda:
+    :param plazo_meses:
+    """
+    
     def __init__(
             self,
             tipo_institucion: str = None,
@@ -89,16 +100,6 @@ class DatosPrestamoType(XElement):
             moneda: str = None,
             plazo_meses: str = None,
     ): 
-        """
-        
-        :param tipo_institucion:
-        :param institucion:
-        :param tipo_credito:
-        :param monto_prestamo:
-        :param moneda:
-        :param plazo_meses:
-        """
-        
         super().__init__({
             'TipoInstitucion': tipo_institucion,
             'Institucion': institucion,
@@ -109,22 +110,32 @@ class DatosPrestamoType(XElement):
         })
         
 
-class PrestamoFinancieroType(XElement):
+class PrestamoFinancieroType(ScalarMap):
+    """
+    
+    :param datos_prestamo:
+    """
+    
     def __init__(
             self,
             datos_prestamo: DatosPrestamoType | dict | Sequence[DatosPrestamoType | dict] = None,
     ): 
-        """
-        
-        :param datos_prestamo:
-        """
-        
         super().__init__({
             'DatosPrestamo': datos_prestamo,
         })
         
 
-class AportacionNumerarioTercerosType(XElement):
+class AportacionNumerarioTercerosType(ScalarMap):
+    """
+    
+    :param instrumento_monetario:
+    :param moneda:
+    :param monto_aportacion:
+    :param aportacion_fideicomiso:
+    :param nombre_institucion:
+    :param valor_inmueble_preventa:
+    """
+    
     def __init__(
             self,
             instrumento_monetario: str = None,
@@ -134,16 +145,6 @@ class AportacionNumerarioTercerosType(XElement):
             nombre_institucion: str = None,
             valor_inmueble_preventa: str = None,
     ): 
-        """
-        
-        :param instrumento_monetario:
-        :param moneda:
-        :param monto_aportacion:
-        :param aportacion_fideicomiso:
-        :param nombre_institucion:
-        :param valor_inmueble_preventa:
-        """
-        
         super().__init__({
             'InstrumentoMonetario': instrumento_monetario,
             'Moneda': moneda,
@@ -154,53 +155,53 @@ class AportacionNumerarioTercerosType(XElement):
         })
         
 
-class DatosAportacionTercerosType(XElement):
+class DatosAportacionTercerosType(ScalarMap):
+    """
+    
+    :param aportacion_numerario:
+    :param aportacion_especie:
+    """
+    
     def __init__(
             self,
             aportacion_numerario: AportacionNumerarioTercerosType | dict = None,
             aportacion_especie: AportacionEspecieType | dict = None,
     ): 
-        """
-        
-        :param aportacion_numerario:
-        :param aportacion_especie:
-        """
-        
         super().__init__({
             'AportacionNumerario': aportacion_numerario,
             'AportacionEspecie': aportacion_especie,
         })
         
 
-class TercerosAportacionType(XElement):
+class TercerosAportacionType(ScalarMap):
+    """
+    
+    :param datos_aportacion:
+    """
+    
     def __init__(
             self,
             datos_aportacion: DatosAportacionTercerosType | dict,
     ): 
-        """
-        
-        :param datos_aportacion:
-        """
-        
         super().__init__({
             'DatosAportacion': datos_aportacion,
         })
         
 
-class FideicomisoType(XElement):
+class FideicomisoType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str = None,
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'Rfc': rfc,
@@ -208,7 +209,17 @@ class FideicomisoType(XElement):
         })
         
 
-class PersonaMoralType(XElement):
+class PersonaMoralType(ScalarMap):
+    """
+    
+    :param representante_apoderado:
+    :param denominacion_razon:
+    :param fecha_constitucion:
+    :param rfc:
+    :param pais_nacionalidad:
+    :param giro_mercantil:
+    """
+    
     def __init__(
             self,
             representante_apoderado: RepresentanteApoderadoType | dict,
@@ -218,16 +229,6 @@ class PersonaMoralType(XElement):
             pais_nacionalidad: str = None,
             giro_mercantil: str = None,
     ): 
-        """
-        
-        :param representante_apoderado:
-        :param denominacion_razon:
-        :param fecha_constitucion:
-        :param rfc:
-        :param pais_nacionalidad:
-        :param giro_mercantil:
-        """
-        
         super().__init__({
             'RepresentanteApoderado': representante_apoderado,
             'DenominacionRazon': denominacion_razon,
@@ -238,7 +239,19 @@ class PersonaMoralType(XElement):
         })
         
 
-class PersonaFisicaType(XElement):
+class PersonaFisicaType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    :param pais_nacionalidad:
+    :param actividad_economica:
+    """
+    
     def __init__(
             self,
             nombre: str = None,
@@ -250,18 +263,6 @@ class PersonaFisicaType(XElement):
             pais_nacionalidad: str = None,
             actividad_economica: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        :param pais_nacionalidad:
-        :param actividad_economica:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -274,20 +275,20 @@ class PersonaFisicaType(XElement):
         })
         
 
-class TipoPersonaType(XElement):
+class TipoPersonaType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaType | dict = None,
             persona_moral: PersonaMoralType | dict = None,
             fideicomiso: FideicomisoType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -295,7 +296,15 @@ class TipoPersonaType(XElement):
         })
         
 
-class DatosTerceroType(XElement):
+class DatosTerceroType(ScalarMap):
+    """
+    
+    :param tipo_persona_tercero:
+    :param detalle_aportaciones:
+    :param tipo_tercero:
+    :param descripcion_tercero:
+    """
+    
     def __init__(
             self,
             tipo_persona_tercero: TipoPersonaType | dict,
@@ -303,14 +312,6 @@ class DatosTerceroType(XElement):
             tipo_tercero: str = None,
             descripcion_tercero: str = None,
     ): 
-        """
-        
-        :param tipo_persona_tercero:
-        :param detalle_aportaciones:
-        :param tipo_tercero:
-        :param descripcion_tercero:
-        """
-        
         super().__init__({
             'TipoPersonaTercero': tipo_persona_tercero,
             'DetalleAportaciones': detalle_aportaciones,
@@ -319,86 +320,86 @@ class DatosTerceroType(XElement):
         })
         
 
-class DetalleTercerosType(XElement):
+class DetalleTercerosType(ScalarMap):
+    """
+    
+    :param datos_tercero:
+    """
+    
     def __init__(
             self,
             datos_tercero: DatosTerceroType | dict | Sequence[DatosTerceroType | dict] = None,
     ): 
-        """
-        
-        :param datos_tercero:
-        """
-        
         super().__init__({
             'DatosTercero': datos_tercero,
         })
         
 
-class TercerosType(XElement):
+class TercerosType(ScalarMap):
+    """
+    
+    :param detalle_terceros:
+    :param numero_terceros:
+    """
+    
     def __init__(
             self,
             detalle_terceros: DetalleTercerosType | dict,
             numero_terceros: str = None,
     ): 
-        """
-        
-        :param detalle_terceros:
-        :param numero_terceros:
-        """
-        
         super().__init__({
             'DetalleTerceros': detalle_terceros,
             'NumeroTerceros': numero_terceros,
         })
         
 
-class DatosAportacionSociosType(XElement):
+class DatosAportacionSociosType(ScalarMap):
+    """
+    
+    :param aportacion_numerario:
+    :param aportacion_especie:
+    """
+    
     def __init__(
             self,
             aportacion_numerario: AportacionNumerarioType | dict = None,
             aportacion_especie: AportacionEspecieType | dict = None,
     ): 
-        """
-        
-        :param aportacion_numerario:
-        :param aportacion_especie:
-        """
-        
         super().__init__({
             'AportacionNumerario': aportacion_numerario,
             'AportacionEspecie': aportacion_especie,
         })
         
 
-class SociosAportacionType(XElement):
+class SociosAportacionType(ScalarMap):
+    """
+    
+    :param datos_aportacion:
+    """
+    
     def __init__(
             self,
             datos_aportacion: DatosAportacionSociosType | dict,
     ): 
-        """
-        
-        :param datos_aportacion:
-        """
-        
         super().__init__({
             'DatosAportacion': datos_aportacion,
         })
         
 
-class TelefonoType(XElement):
+class TelefonoType(ScalarMap):
+    """
+    
+    :param clave_pais:
+    :param numero_telefono:
+    :param correo_electronico:
+    """
+    
     def __init__(
             self,
             clave_pais: str = None,
             numero_telefono: str = None,
             correo_electronico: str = None,
     ): 
-        """
-        
-        :param clave_pais:
-        :param numero_telefono:
-        :param correo_electronico:
-        """
-        
         super().__init__({
             'ClavePais': clave_pais,
             'NumeroTelefono': numero_telefono,
@@ -406,7 +407,19 @@ class TelefonoType(XElement):
         })
         
 
-class ExtranjeroType(XElement):
+class ExtranjeroType(ScalarMap):
+    """
+    
+    :param pais:
+    :param estado_provincia:
+    :param ciudad_poblacion:
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param numero_interior:
+    :param codigo_postal:
+    """
+    
     def __init__(
             self,
             pais: str = None,
@@ -418,18 +431,6 @@ class ExtranjeroType(XElement):
             numero_interior: str = None,
             codigo_postal: str = None,
     ): 
-        """
-        
-        :param pais:
-        :param estado_provincia:
-        :param ciudad_poblacion:
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param numero_interior:
-        :param codigo_postal:
-        """
-        
         super().__init__({
             'Pais': pais,
             'EstadoProvincia': estado_provincia,
@@ -442,7 +443,16 @@ class ExtranjeroType(XElement):
         })
         
 
-class NacionalType(XElement):
+class NacionalType(ScalarMap):
+    """
+    
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param numero_interior:
+    :param codigo_postal:
+    """
+    
     def __init__(
             self,
             colonia: str = None,
@@ -451,15 +461,6 @@ class NacionalType(XElement):
             numero_interior: str = None,
             codigo_postal: str = None,
     ): 
-        """
-        
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param numero_interior:
-        :param codigo_postal:
-        """
-        
         super().__init__({
             'Colonia': colonia,
             'Calle': calle,
@@ -469,25 +470,35 @@ class NacionalType(XElement):
         })
         
 
-class TipoDomicilioType(XElement):
+class TipoDomicilioType(ScalarMap):
+    """
+    
+    :param nacional:
+    :param extranjero:
+    """
+    
     def __init__(
             self,
             nacional: NacionalType | dict = None,
             extranjero: ExtranjeroType | dict = None,
     ): 
-        """
-        
-        :param nacional:
-        :param extranjero:
-        """
-        
         super().__init__({
             'Nacional': nacional,
             'Extranjero': extranjero,
         })
         
 
-class RepresentanteApoderadoType(XElement):
+class RepresentanteApoderadoType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str = None,
@@ -497,16 +508,6 @@ class RepresentanteApoderadoType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -517,7 +518,16 @@ class RepresentanteApoderadoType(XElement):
         })
         
 
-class PersonaMoralSocioType(XElement):
+class PersonaMoralSocioType(ScalarMap):
+    """
+    
+    :param representante_apoderado:
+    :param denominacion_razon:
+    :param fecha_constitucion:
+    :param pais_nacionalidad:
+    :param giro_mercantil:
+    """
+    
     def __init__(
             self,
             representante_apoderado: RepresentanteApoderadoType | dict,
@@ -526,15 +536,6 @@ class PersonaMoralSocioType(XElement):
             pais_nacionalidad: str = None,
             giro_mercantil: str = None,
     ): 
-        """
-        
-        :param representante_apoderado:
-        :param denominacion_razon:
-        :param fecha_constitucion:
-        :param pais_nacionalidad:
-        :param giro_mercantil:
-        """
-        
         super().__init__({
             'RepresentanteApoderado': representante_apoderado,
             'DenominacionRazon': denominacion_razon,
@@ -544,7 +545,18 @@ class PersonaMoralSocioType(XElement):
         })
         
 
-class PersonaFisicaSocioType(XElement):
+class PersonaFisicaSocioType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param curp:
+    :param pais_nacionalidad:
+    :param actividad_economica:
+    """
+    
     def __init__(
             self,
             nombre: str = None,
@@ -555,17 +567,6 @@ class PersonaFisicaSocioType(XElement):
             pais_nacionalidad: str = None,
             actividad_economica: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param curp:
-        :param pais_nacionalidad:
-        :param actividad_economica:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -577,20 +578,20 @@ class PersonaFisicaSocioType(XElement):
         })
         
 
-class TipoPersonaSocioType(XElement):
+class TipoPersonaSocioType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaSocioType | dict = None,
             persona_moral: PersonaMoralSocioType | dict = None,
             fideicomiso: FideicomisoType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -598,7 +599,17 @@ class TipoPersonaSocioType(XElement):
         })
         
 
-class DatosSocioType(XElement):
+class DatosSocioType(ScalarMap):
+    """
+    
+    :param tipo_persona_socio:
+    :param tipo_domicilio_socio:
+    :param detalle_aportaciones:
+    :param aportacion_anterior_socio:
+    :param rfc_socio:
+    :param telefono:
+    """
+    
     def __init__(
             self,
             tipo_persona_socio: TipoPersonaSocioType | dict,
@@ -608,16 +619,6 @@ class DatosSocioType(XElement):
             rfc_socio: str = None,
             telefono: TelefonoType | dict = None,
     ): 
-        """
-        
-        :param tipo_persona_socio:
-        :param tipo_domicilio_socio:
-        :param detalle_aportaciones:
-        :param aportacion_anterior_socio:
-        :param rfc_socio:
-        :param telefono:
-        """
-        
         super().__init__({
             'TipoPersonaSocio': tipo_persona_socio,
             'TipoDomicilioSocio': tipo_domicilio_socio,
@@ -628,58 +629,67 @@ class DatosSocioType(XElement):
         })
         
 
-class DetalleSociosType(XElement):
+class DetalleSociosType(ScalarMap):
+    """
+    
+    :param datos_socio:
+    """
+    
     def __init__(
             self,
             datos_socio: DatosSocioType | dict | Sequence[DatosSocioType | dict] = None,
     ): 
-        """
-        
-        :param datos_socio:
-        """
-        
         super().__init__({
             'DatosSocio': datos_socio,
         })
         
 
-class SociosType(XElement):
+class SociosType(ScalarMap):
+    """
+    
+    :param detalle_socios:
+    :param numero_socios:
+    """
+    
     def __init__(
             self,
             detalle_socios: DetalleSociosType | dict,
             numero_socios: str = None,
     ): 
-        """
-        
-        :param detalle_socios:
-        :param numero_socios:
-        """
-        
         super().__init__({
             'DetalleSocios': detalle_socios,
             'NumeroSocios': numero_socios,
         })
         
 
-class AportacionEspecieType(XElement):
+class AportacionEspecieType(ScalarMap):
+    """
+    
+    :param descripcion_bien:
+    :param monto_estimado:
+    """
+    
     def __init__(
             self,
             descripcion_bien: str = None,
             monto_estimado: str = None,
     ): 
-        """
-        
-        :param descripcion_bien:
-        :param monto_estimado:
-        """
-        
         super().__init__({
             'DescripcionBien': descripcion_bien,
             'MontoEstimado': monto_estimado,
         })
         
 
-class AportacionNumerarioType(XElement):
+class AportacionNumerarioType(ScalarMap):
+    """
+    
+    :param instrumento_monetario:
+    :param moneda:
+    :param monto_aportacion:
+    :param aportacion_fideicomiso:
+    :param nombre_institucion:
+    """
+    
     def __init__(
             self,
             instrumento_monetario: str = None,
@@ -688,15 +698,6 @@ class AportacionNumerarioType(XElement):
             aportacion_fideicomiso: str = None,
             nombre_institucion: str = None,
     ): 
-        """
-        
-        :param instrumento_monetario:
-        :param moneda:
-        :param monto_aportacion:
-        :param aportacion_fideicomiso:
-        :param nombre_institucion:
-        """
-        
         super().__init__({
             'InstrumentoMonetario': instrumento_monetario,
             'Moneda': moneda,
@@ -706,40 +707,50 @@ class AportacionNumerarioType(XElement):
         })
         
 
-class DatosAportacionType(XElement):
+class DatosAportacionType(ScalarMap):
+    """
+    
+    :param aportacion_numerario:
+    :param aportacion_especie:
+    """
+    
     def __init__(
             self,
             aportacion_numerario: AportacionNumerarioType | dict = None,
             aportacion_especie: AportacionEspecieType | dict = None,
     ): 
-        """
-        
-        :param aportacion_numerario:
-        :param aportacion_especie:
-        """
-        
         super().__init__({
             'AportacionNumerario': aportacion_numerario,
             'AportacionEspecie': aportacion_especie,
         })
         
 
-class RecursosPropiosType(XElement):
+class RecursosPropiosType(ScalarMap):
+    """
+    
+    :param datos_aportacion:
+    """
+    
     def __init__(
             self,
             datos_aportacion: DatosAportacionType | dict | Sequence[DatosAportacionType | dict] = None,
     ): 
-        """
-        
-        :param datos_aportacion:
-        """
-        
         super().__init__({
             'DatosAportacion': datos_aportacion,
         })
         
 
-class TipoAportacionType(XElement):
+class TipoAportacionType(ScalarMap):
+    """
+    
+    :param recursos_propios:
+    :param socios:
+    :param terceros:
+    :param prestamo_financiero:
+    :param prestamo_no_financiero:
+    :param financiamiento_bursatil:
+    """
+    
     def __init__(
             self,
             recursos_propios: RecursosPropiosType | dict = None,
@@ -749,16 +760,6 @@ class TipoAportacionType(XElement):
             prestamo_no_financiero: PrestamoNoFinancieroType | dict = None,
             financiamiento_bursatil: FinanciamientoBursatilType | dict = None,
     ): 
-        """
-        
-        :param recursos_propios:
-        :param socios:
-        :param terceros:
-        :param prestamo_financiero:
-        :param prestamo_no_financiero:
-        :param financiamiento_bursatil:
-        """
-        
         super().__init__({
             'RecursosPropios': recursos_propios,
             'Socios': socios,
@@ -769,25 +770,38 @@ class TipoAportacionType(XElement):
         })
         
 
-class AportacionesType(XElement):
+class AportacionesType(ScalarMap):
+    """
+    
+    :param fecha_aportacion:
+    :param tipo_aportacion:
+    """
+    
     def __init__(
             self,
             fecha_aportacion: date = None,
             tipo_aportacion: TipoAportacionType | dict | Sequence[TipoAportacionType | dict] = None,
     ): 
-        """
-        
-        :param fecha_aportacion:
-        :param tipo_aportacion:
-        """
-        
         super().__init__({
             'FechaAportacion': fecha_aportacion,
             'TipoAportacion': tipo_aportacion,
         })
         
 
-class CaracteristicasDesarrolloType(XElement):
+class CaracteristicasDesarrolloType(ScalarMap):
+    """
+    
+    :param codigo_postal:
+    :param colonia:
+    :param calle:
+    :param tipo_desarrollo:
+    :param monto_desarrollo:
+    :param unidades_comercializadas:
+    :param costo_unidad:
+    :param otras_empresas:
+    :param descripcion_desarrollo:
+    """
+    
     def __init__(
             self,
             codigo_postal: str,
@@ -800,19 +814,6 @@ class CaracteristicasDesarrolloType(XElement):
             otras_empresas: str,
             descripcion_desarrollo: str = None,
     ): 
-        """
-        
-        :param codigo_postal:
-        :param colonia:
-        :param calle:
-        :param tipo_desarrollo:
-        :param monto_desarrollo:
-        :param unidades_comercializadas:
-        :param costo_unidad:
-        :param otras_empresas:
-        :param descripcion_desarrollo:
-        """
-        
         super().__init__({
             'CodigoPostal': codigo_postal,
             'Colonia': colonia,
@@ -826,7 +827,16 @@ class CaracteristicasDesarrolloType(XElement):
         })
         
 
-class DatosDesarrolloType(XElement):
+class DatosDesarrolloType(ScalarMap):
+    """
+    
+    :param objeto_aviso_anterior:
+    :param modificacion:
+    :param entidad_federativa:
+    :param registro_licencia:
+    :param caracteristicas_desarrollo:
+    """
+    
     def __init__(
             self,
             objeto_aviso_anterior: str,
@@ -835,15 +845,6 @@ class DatosDesarrolloType(XElement):
             registro_licencia: str,
             caracteristicas_desarrollo: CaracteristicasDesarrolloType | dict | Sequence[CaracteristicasDesarrolloType | dict],
     ): 
-        """
-        
-        :param objeto_aviso_anterior:
-        :param modificacion:
-        :param entidad_federativa:
-        :param registro_licencia:
-        :param caracteristicas_desarrollo:
-        """
-        
         super().__init__({
             'ObjetoAvisoAnterior': objeto_aviso_anterior,
             'Modificacion': modificacion,
@@ -853,35 +854,35 @@ class DatosDesarrolloType(XElement):
         })
         
 
-class DesarrollosInmobiliariosType(XElement):
+class DesarrollosInmobiliariosType(ScalarMap):
+    """
+    
+    :param datos_desarrollo:
+    """
+    
     def __init__(
             self,
             datos_desarrollo: DatosDesarrolloType | dict | Sequence[DatosDesarrolloType | dict],
     ): 
-        """
-        
-        :param datos_desarrollo:
-        """
-        
         super().__init__({
             'DatosDesarrollo': datos_desarrollo,
         })
         
 
-class DatosOperacionType(XElement):
+class DatosOperacionType(ScalarMap):
+    """
+    
+    :param tipo_operacion:
+    :param desarrollos_inmobiliarios:
+    :param aportaciones:
+    """
+    
     def __init__(
             self,
             tipo_operacion: str,
             desarrollos_inmobiliarios: DesarrollosInmobiliariosType | dict,
             aportaciones: AportacionesType | dict,
     ): 
-        """
-        
-        :param tipo_operacion:
-        :param desarrollos_inmobiliarios:
-        :param aportaciones:
-        """
-        
         super().__init__({
             'TipoOperacion': tipo_operacion,
             'DesarrollosInmobiliarios': desarrollos_inmobiliarios,
@@ -889,58 +890,67 @@ class DatosOperacionType(XElement):
         })
         
 
-class DetalleOperacionesType(XElement):
+class DetalleOperacionesType(ScalarMap):
+    """
+    
+    :param datos_operacion:
+    """
+    
     def __init__(
             self,
             datos_operacion: DatosOperacionType | dict | Sequence[DatosOperacionType | dict],
     ): 
-        """
-        
-        :param datos_operacion:
-        """
-        
         super().__init__({
             'DatosOperacion': datos_operacion,
         })
         
 
-class AlertaType(XElement):
+class AlertaType(ScalarMap):
+    """
+    
+    :param tipo_alerta:
+    :param descripcion_alerta:
+    """
+    
     def __init__(
             self,
             tipo_alerta: str,
             descripcion_alerta: str = None,
     ): 
-        """
-        
-        :param tipo_alerta:
-        :param descripcion_alerta:
-        """
-        
         super().__init__({
             'TipoAlerta': tipo_alerta,
             'DescripcionAlerta': descripcion_alerta,
         })
         
 
-class ModificatorioType(XElement):
+class ModificatorioType(ScalarMap):
+    """
+    
+    :param folio_modificacion:
+    :param descripcion_modificacion:
+    """
+    
     def __init__(
             self,
             folio_modificacion: str,
             descripcion_modificacion: str,
     ): 
-        """
-        
-        :param folio_modificacion:
-        :param descripcion_modificacion:
-        """
-        
         super().__init__({
             'FolioModificacion': folio_modificacion,
             'DescripcionModificacion': descripcion_modificacion,
         })
         
 
-class AvisoType(XElement):
+class AvisoType(ScalarMap):
+    """
+    
+    :param referencia_aviso:
+    :param prioridad:
+    :param alerta:
+    :param detalle_operaciones:
+    :param modificatorio:
+    """
+    
     def __init__(
             self,
             referencia_aviso: str,
@@ -949,15 +959,6 @@ class AvisoType(XElement):
             detalle_operaciones: DetalleOperacionesType | dict,
             modificatorio: ModificatorioType | dict = None,
     ): 
-        """
-        
-        :param referencia_aviso:
-        :param prioridad:
-        :param alerta:
-        :param detalle_operaciones:
-        :param modificatorio:
-        """
-        
         super().__init__({
             'ReferenciaAviso': referencia_aviso,
             'Prioridad': prioridad,
@@ -967,7 +968,15 @@ class AvisoType(XElement):
         })
         
 
-class SujetoObligadoType(XElement):
+class SujetoObligadoType(ScalarMap):
+    """
+    
+    :param clave_sujeto_obligado:
+    :param clave_actividad:
+    :param clave_entidad_colegiada:
+    :param exento:
+    """
+    
     def __init__(
             self,
             clave_sujeto_obligado: str,
@@ -975,14 +984,6 @@ class SujetoObligadoType(XElement):
             clave_entidad_colegiada: str = None,
             exento: str = None,
     ): 
-        """
-        
-        :param clave_sujeto_obligado:
-        :param clave_actividad:
-        :param clave_entidad_colegiada:
-        :param exento:
-        """
-        
         super().__init__({
             'ClaveSujetoObligado': clave_sujeto_obligado,
             'ClaveActividad': clave_actividad,
@@ -991,20 +992,20 @@ class SujetoObligadoType(XElement):
         })
         
 
-class InformeType(XElement):
+class InformeType(ScalarMap):
+    """
+    
+    :param mes_reportado:
+    :param sujeto_obligado:
+    :param aviso:
+    """
+    
     def __init__(
             self,
             mes_reportado: str,
             sujeto_obligado: SujetoObligadoType | dict,
             aviso: AvisoType | dict | Sequence[AvisoType | dict] = None,
     ): 
-        """
-        
-        :param mes_reportado:
-        :param sujeto_obligado:
-        :param aviso:
-        """
-        
         super().__init__({
             'MesReportado': mes_reportado,
             'SujetoObligado': sujeto_obligado,
@@ -1012,21 +1013,21 @@ class InformeType(XElement):
         })
         
 
-class ArchivoType(XElement):
+class ArchivoType(ScalarMap):
+    """
+    
+    :param informe:
+    """
+    
     def __init__(
             self,
             informe: InformeType | dict | Sequence[InformeType | dict],
     ): 
-        """
-        
-        :param informe:
-        """
-        
         super().__init__({
             'Informe': informe,
         })
         
 
-class Archivo(ArchivoType):
+class Archivo(ArchivoType, XElement):
     tag = '{http://www.uif.shcp.gob.mx/recepcion/din}archivo'
 
