@@ -23,6 +23,8 @@ __all__ = [
     'Pais'
 ]
 
+from ..zip import zip_create, ZipData
+
 current_dir = os.path.dirname(__file__)
 
 VERSION_DEMC = 10
@@ -412,25 +414,9 @@ class DIOT(Representable):
             return b.getvalue()
 
     def _zip_write(self, target: BytesIO, tmp_filename):
-        p = target.tell()
-        filename = f"C:\\{tmp_filename}.txt"
-
-        with ZipFile(target, "w") as myzip:
-            zinfo = ZipInfo(
-                filename=filename
-            )
-            zinfo.filename = filename
-            zinfo.compress_type = 8
-            zinfo.create_system = 0
-
-            with myzip.open(zinfo, 'w') as stream:
-                zinfo.flag_bits = 2056
-                zinfo.external_attr = 0
-                w = DIOTWriter(stream)
-                self.render(w)
-
-        with target.getbuffer() as view:  # change zip flag bytes
-            view[p + 6:p + 8] = b"\x08\x08"
+        zip_create(target, [
+            ZipData(f"C:\\{tmp_filename}.txt", lambda s: self.render(DIOTWriter(s)))
+        ])
 
     def _encrypted_bytes(self, tmp_filename) -> bytes:
         with BytesIO() as b:
